#Author: Karina Tiemi Kato
#Description by: Isabella Firmino
#Combinação das imagens

import numpy as np

#pacote de processamento de imagens
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity

#achar diferença entre duas imagens
def find_difference(image1, image2):

    #verificando se os shapes são iguais e exibindo msg caso não seja
    assert image1.shape == image2.shape, "Specify 2 images with the same shape."

    #conversão pra tons de cinza das duas imagens de entrada, usando o modulo de color do scikit image
    gray_image1 = rgb2gray(image1)
    gray_image2 = rgb2gray(image2)

    #usando o structural_similarity do módulo de metrics, fazemos a chamada passando as imagens com tons de cinza pra achar o score e difference_image
    #o score é um valor de 0 a 1, que diz o quanto as imagens são similares, e o difference_image é a imagem de diferença entre as duas imagens de entrada
    (score, difference_image) = structural_similarity(gray_image1, gray_image2, full=True)

    #printando score e normalizando o difference_image, pra ficar mais fácil de identificar na imagem de diferença na hora que formos plotar 
    # (pra que se as imagens forem mt parecidas, não fique valores mt pequenos, por isso a normalização)
    print("Similarity of the images:", score)
    normalized_difference_image = (difference_image-np.min(difference_image))/(np.max(difference_image)-np.min(difference_image))
    return normalized_difference_image

def transfer_histogram(image1, image2):
    #função do módulo exposure do scikit image
    matched_image = match_histograms(image1, image2, multichannel=True)
    return matched_image


#Author: Karina Tiemi Kato
#transformação para uma imagem apenas

from skimage.transform import resize

#passando imagem e proporção, a ideia é utilizar quando forem imagens mt grandes, p diminuí-las
def resize_image(image, proportion):

    #proporção de 0 a 1, lançando msg se não for de 0 a 1
    assert 0 <= proportion <=1, "Specify a valid proportion between 0 and 1."

    #pegando da imagem o shape 0 e 1 e multiplicando pela proporção pra pegar a altura e largura depois de aplicada a proporção que queremos
    #round usado para ser um valor inteiro, pois precisa ser passado como inteiro na image_resized
    height = round(image.shape[0]*proportion)
    width = round(image.shape[1]*proportion)

    #função do transform, passando valor de largura e altura, e imagem que queremos fazer resize
    image_resized = resize(image, (height, width), anti_aliasing=True)
    return image_resized


from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

setup(
    name="img-processing-pcg",
    version="0.0.1",
    author="Isabella Firmino",
    author_email="isabella.mfbr@gmail.com",
    description="Test version - Image processing. This project belongs to Karina Tiemi Kato, Tech Lead, Machine Learning Engineer, Data Scientist Specialist. This package is a demo for simulation of upload on the Test Pypi website, and it's from class of the Bootcamp Geração Tech Unimed-BH - Ciência de Dados.",
    long_description=page_description,
    long_description_content_type="text/markdown",
    # url="https://github.com/isobew/trilha-python/tree/main/pacotes_process_img/image-processing-package"
    packages=find_packages(),
    install_requires=requirements,
    python_requires='>=3.8',
)